<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace FiloBlu\DisableShop\Block;

use Magento\Framework\View\Element\Template;

/**
 * Main contact form block
 *
 * @api
 * @since 100.0.2
 */
class InfoForm extends Template
{
    /**
     * InfoForm constructor.
     * @param \Magento\Catalog\Block\Product\View $product
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     * @param Template\Context $context
     * @param array $data
     */
    public function __construct(
        \Magento\Catalog\Block\Product\View $product,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        Template\Context $context,
        array $data = [])
    {
        parent::__construct($context, $data);
        $this->_product = $product;
        $this->_scopeConfig = $scopeConfig;
        $this->_isScopePrivate = true;
    }

    /**
     * @return string
     */
    public function getFormAction()
    {
        $actionUrl = $this->_storeManager->getStore()->getBaseUrl() . 'askproductinfo/index/productinfo';
        return $actionUrl;
    }

    /**
     * @return string
     */
    public function getProductSku()
    {
        return $this->_product->getProduct()->getSku();
    }

    /**
     * @return string
     */
    public function getProductName()
    {
        return $this->_product->getProduct()->getName();
    }

    public function isProductDisabled() {
        return $this->_product->getProduct()->getDisableShop() == 1;
    }

    /**
     * @return mixed
     */
    public function getInfoTitle()
    {
        return $this->_scopeConfig->getValue(
            'filoblu_disableshop_section/ask_info/ask_info_title',
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * @return mixed
     */
    public function getInfoPrivacy()
    {
        return $this->_scopeConfig->getValue(
            'filoblu_disableshop_section/ask_info/ask_info_privacy',
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }
}
